##############################################
#
# text_cell
# Package | Text Cell Module.
#
# Daniel Bakas Amuchastegui
# February, 2020
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from . import text_cell
from .text_cell import *