##############################################
#
# genealogical_tree
# Module | genealogical_tree Module.
#
# Daniel Bakas Amuchastegui
# March 16, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from .network import Network

class GenealogicalTree(Network):
    pass