##############################################
#
# graph
# Module | Graph Module.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from ...core.model import Model

class Graph(Model):
    pass