##############################################
#
# text_cell
# Module | Text Cell Module.
#
# Daniel Bakas Amuchastegui
# February 20, 2020
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from ..cell import Cell

class TextCell(Cell):
    pass