##############################################
#
# table
# Module | Displays an indexed, structured, table representating a given Resource's content.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from ..core.model import Model

class Table(Model):
    pass