##############################################
#
# image_cell
# Package | Image Cell Module.
#
# Daniel Bakas Amuchastegui
# February, 2020
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from . import multimedia_cell
from .multimedia_cell import *