##############################################
#
# chart
# Module | Chart Module.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################

from .graph import Graph

class Chart(Graph):
    pass