##############################################
#
# av_reality
# Package | Augmented and Virtual Reality Package.
#
# Author: Daniel Bakas Amuchastegui
# September 6, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
#############################################
